summaryrefslogtreecommitdiff
path: root/src/mongo/db/transaction_participant.h
diff options
context:
space:
mode:
authorA. Jesse Jiryu Davis <jesse@mongodb.com>2019-02-05 17:32:20 -0500
committerA. Jesse Jiryu Davis <jesse@mongodb.com>2019-02-20 18:01:09 -0500
commit951a9eaba9bf9069866aa04e9a450d25cff74d1a (patch)
treeb8b6f750b55eabf42d1e0094f65e18b16f8adae9 /src/mongo/db/transaction_participant.h
parent5fe1af5f8e845f736f4e76d7a8d47675b6507a6c (diff)
downloadmongo-951a9eaba9bf9069866aa04e9a450d25cff74d1a.tar.gz
SERVER-38906 Txns read without timestamp by default
Diffstat (limited to 'src/mongo/db/transaction_participant.h')
-rw-r--r--src/mongo/db/transaction_participant.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mongo/db/transaction_participant.h b/src/mongo/db/transaction_participant.h
index f90a12ed77b..242afe49855 100644
--- a/src/mongo/db/transaction_participant.h
+++ b/src/mongo/db/transaction_participant.h
@@ -63,13 +63,13 @@ extern AtomicWord<int> transactionLifetimeLimitSeconds;
* concern level specified as 'snapshot', we will use 'kAllCommitted' which ensures a snapshot
* with no 'holes'; that is, it is a state of the system that could be reconstructed from
* the oplog. For transactions with read concern level specified as 'local' or 'majority',
* we will use 'kLastApplied' which gives us the most recent snapshot. This snapshot may
* reflect oplog 'holes' from writes earlier than the last applied write which have not yet
* completed. Using 'kLastApplied' ensures that transactions with mode 'local' are always able to
* read writes from earlier transactions with mode 'local' on the same connection.
*/
enum class SpeculativeTransactionOpTime {
- kLastApplied,
+ kNoTimestamp,
kAllCommitted,
};
@@ -63,13 +63,13 @@ extern AtomicWord<int> transactionLifetimeLimitSeconds;
* with no 'holes'; that is, it is a state of the system that could be reconstructed from
* the oplog. For transactions with read concern level specified as 'local' or 'majority',
- * we will use 'kLastApplied' which gives us the most recent snapshot. This snapshot may
+ * we will use 'kNoTimestamp' which gives us the most recent snapshot. This snapshot may
* reflect oplog 'holes' from writes earlier than the last applied write which have not yet
@@ -63,13 +63,13 @@ extern AtomicWord<int> transactionLifetimeLimitSeconds;
* reflect oplog 'holes' from writes earlier than the last applied write which have not yet
- * completed. Using 'kLastApplied' ensures that transactions with mode 'local' are always able to
+ * completed. Using 'kNoTimestamp' ensures that transactions with mode 'local' are always able to
* read writes from earlier transactions with mode 'local' on the same connection.
*/